@@ -4,9 +4,9 @@ from datetime import datetime, timedelta
 from pathlib import Path
 from typing import Set, Union
 
-from nibe.coil import Coil
+from nibe.coil import Coil, CoilData
 from nibe.connection import Connection
-from nibe.exceptions import CoilWriteException, CoilNotFoundException
+from nibe.exceptions import WriteException, CoilNotFoundException
 from nibe.heatpump import HeatPump
 from slugify import slugify
 
@@ -77,9 +77,9 @@ class Service(MqttHandler):
     def handle_coil_set(self, name, value: str):
         try:
             coil = self.heatpump.get_coil_by_name(name)
-            coil.value = value
+            coil_data = CoilData(coil, value)
 
-            asyncio.create_task(self.write_coil(coil))
+            asyncio.create_task(self.write_coil(coil_data))
         except (AssertionError, CoilNotFoundException) as e:
             logger.error(e)
         except Exception as e:
@@ -88,26 +88,18 @@ class Service(MqttHandler):
     async def read_coil(self, coil: Coil):
         return await self.connection.read_coil(coil)
 
-    async def write_coil(self, coil: Coil) -> None:
+    async def write_coil(self, coil_data: CoilData) -> None:
         refresh_required = True
         try:
-            coil_value = coil.value
-            await self.connection.write_coil(coil)
-            if coil_value == coil.value:  # if coil value did not change while we were writing, just publish to MQTT
-                self.on_coil_update(coil)
-                refresh_required = False
-            else:  # if value has changed we do not know what is the current state
-                logger.info(
-                    f"{coil.name} value has changed while we were writing: {coil_value} -> {coil.value}"
-                )
-        except CoilWriteException as e:
+            await self.connection.write_coil(coil_data)
+        except WriteException as e:
             logger.error(e)
         except Exception as e:
             logger.exception("Unhandled exception during write", e)
 
         if refresh_required:
             try:
-                await self.read_coil(coil)
+                await self.read_coil(coil_data.coil)
             except Exception as e:
                 logger.exception("Unhandled exception during read", e)
 
@@ -122,15 +114,18 @@ class Service(MqttHandler):
 
         self.mqtt_client.start()
 
-    def on_coil_update(self, coil: Coil):
-        if coil not in self.announced_coils:
-            self.mqtt_client.publish_discovery(coil, self._get_device_info())
-            self.announced_coils.add(coil)
+    def on_coil_update(self, coil_data: CoilData):
+        if coil_data.coil not in self.announced_coils:
+            self.mqtt_client.publish_discovery(coil_data.coil, self._get_device_info())
+            self.announced_coils.add(coil_data.coil)
 
-        self.mqtt_client.publish_coil_state(coil)
+        self.mqtt_client.publish_coil_state(coil_data)
 
         if self.poller is not None:
-            self.poller.register_update(coil)
+            self.poller.register_update(coil_data.coil)
+
+    def on_mqtt_connected(self):
+        self.announced_coils.clear()
 
 
 class PollService:
